pub fn image_base() -> &'static IMAGE_DOS_HEADERExpand description
Gets the base address of the module this code is linked with.
This uses a linker pseudovariable and is only available on windows targets.
pub fn image_base() -> &'static IMAGE_DOS_HEADERGets the base address of the module this code is linked with.
This uses a linker pseudovariable and is only available on windows targets.